==> drupal-9.1.8.tar.gz: drupal-9.1.8/core/tests/Drupal/KernelTests/Core/Database/InsertDefaultsTest.php <==
<?php

namespace Drupal\KernelTests\Core\Database;

use Drupal\Core\Database\Query\NoFieldsException;

/**
 * Tests the Insert query builder with default values.
 *
 * @group Database
 */
class InsertDefaultsTest extends DatabaseTestBase {

  /**
   * Tests that we can run a query that uses default values for everything.
   */
  public function testDefaultInsert() {
    $query = $this->connection->insert('test')->useDefaults(['job']);
    $id = $query->execute();

    $schema = drupal_get_module_schema('database_test', 'test');

    $job = $this->connection->query('SELECT [job] FROM {test} WHERE [id] = :id', [':id' => $id])->fetchField();
    $this->assertEqual($schema['fields']['job']['default'], $job, 'Default field value is set.');
  }

  /**
   * Tests that no action will be preformed if no fields are specified.
   */
  public function testDefaultEmptyInsert() {
    $num_records_before = (int) $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();

    try {
      $this->connection->insert('test')->execute();
      // This is only executed if no exception has been thrown.
      $this->fail('Expected exception NoFieldsException has not been thrown.');
    }
    catch (NoFieldsException $e) {
      // Expected exception; just continue testing.
    }

    $num_records_after = (int) $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
    $this->assertSame($num_records_before, $num_records_after, 'Do nothing as no fields are specified.');
  }

  /**
   * Tests that we can insert fields with values and defaults in the same query.
   */
  public function testDefaultInsertWithFields() {
    $query = $this->connection->insert('test')
      ->fields(['name' => 'Bob'])
      ->useDefaults(['job']);
    $id = $query->execute();

    $schema = drupal_get_module_schema('database_test', 'test');

    $job = $this->connection->query('SELECT [job] FROM {test} WHERE [id] = :id', [':id' => $id])->fetchField();
    $this->assertEqual($schema['fields']['job']['default'], $job, 'Default field value is set.');
  }

}

==> drupal-9.1.11.tar.gz: drupal-9.1.11/core/tests/Drupal/KernelTests/Core/Database/InsertDefaultsTest.php <==
<?php

namespace Drupal\KernelTests\Core\Database;

use Drupal\Core\Database\Query\NoFieldsException;

/**
 * Tests the Insert query builder with default values.
 *
 * @group Database
 */
class InsertDefaultsTest extends DatabaseTestBase {

  /**
   * Tests that we can run a query that uses default values for everything.
   */
  public function testDefaultInsert() {
    $query = $this->connection->insert('test')->useDefaults(['job']);
    $id = $query->execute();

    $schema = drupal_get_module_schema('database_test', 'test');

    $job = $this->connection->query('SELECT [job] FROM {test} WHERE [id] = :id', [':id' => $id])->fetchField();
    $this->assertEquals($schema['fields']['job']['default'], $job, 'Default field value is set.');
  }

  /**
   * Tests that no action will be preformed if no fields are specified.
   */
  public function testDefaultEmptyInsert() {
    $num_records_before = (int) $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();

    try {
      $this->connection->insert('test')->execute();
      // This is only executed if no exception has been thrown.
      $this->fail('Expected exception NoFieldsException has not been thrown.');
    }
    catch (NoFieldsException $e) {
      // Expected exception; just continue testing.
    }

    $num_records_after = (int) $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
    $this->assertSame($num_records_before, $num_records_after, 'Do nothing as no fields are specified.');
  }

  /**
   * Tests that we can insert fields with values and defaults in the same query.
   */
  public function testDefaultInsertWithFields() {
    $query = $this->connection->insert('test')
      ->fields(['name' => 'Bob'])
      ->useDefaults(['job']);
    $id = $query->execute();

    $schema = drupal_get_module_schema('database_test', 'test');

    $job = $this->connection->query('SELECT [job] FROM {test} WHERE [id] = :id', [':id' => $id])->fetchField();
    $this->assertEquals($schema['fields']['job']['default'], $job, 'Default field value is set.');
  }

}
